//------------------------------------------------------------------------------
// <auto-generated>
//     This code was generated by a tool.
//     Runtime Version:4.0.30319.34209
//
//     Changes to this file may cause incorrect behavior and will be lost if
//     the code is regenerated.
// </auto-generated>
//------------------------------------------------------------------------------

namespace LibCECTray.Properties {
    using System;
    
    
    /// <summary>
    ///   A strongly-typed resource class, for looking up localized strings, etc.
    /// </summary>
    // This class was auto-generated by the StronglyTypedResourceBuilder
    // class via a tool like ResGen or Visual Studio.
    // To add or remove a member, edit your .ResX file then rerun ResGen
    // with the /str option, or rebuild your VS project.
    [global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "4.0.0.0")]
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
    [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
    internal class Resources {
        
        private static global::System.Resources.ResourceManager resourceMan;
        
        private static global::System.Globalization.CultureInfo resourceCulture;
        
        [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
        internal Resources() {
        }
        
        /// <summary>
        ///   Returns the cached ResourceManager instance used by this class.
        /// </summary>
        [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
        internal static global::System.Resources.ResourceManager ResourceManager {
            get {
                if (object.ReferenceEquals(resourceMan, null)) {
                    global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("LibCECTray.Properties.Resources", typeof(Resources).Assembly);
                    resourceMan = temp;
                }
                return resourceMan;
            }
        }
        
        /// <summary>
        ///   Overrides the current thread's CurrentUICulture property for all
        ///   resource lookups using this strongly typed resource class.
        /// </summary>
        [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
        internal static global::System.Globalization.CultureInfo Culture {
            get {
                return resourceCulture;
            }
            set {
                resourceCulture = value;
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to libCEC v{0} - client v{1}.
        /// </summary>
        internal static string about_libcec_version {
            get {
                return ResourceManager.GetString("about_libcec_version", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Activating the source.
        /// </summary>
        internal static string action_activating_source {
            get {
                return ResourceManager.GetString("action_activating_source", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Checking if {0} is present.
        /// </summary>
        internal static string action_check_device_present {
            get {
                return ResourceManager.GetString("action_check_device_present", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Detecting AVR device.
        /// </summary>
        internal static string action_detecting_avr {
            get {
                return ResourceManager.GetString("action_detecting_avr", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Detecting AVR vendor.
        /// </summary>
        internal static string action_detecting_avr_vendor {
            get {
                return ResourceManager.GetString("action_detecting_avr_vendor", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Detecting TV vendor.
        /// </summary>
        internal static string action_detecting_tv_vendor {
            get {
                return ResourceManager.GetString("action_detecting_tv_vendor", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Opening connection.
        /// </summary>
        internal static string action_opening_connection {
            get {
                return ResourceManager.GetString("action_opening_connection", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Polling active devices.
        /// </summary>
        internal static string action_polling_active_devices {
            get {
                return ResourceManager.GetString("action_polling_active_devices", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Reading device configuration.
        /// </summary>
        internal static string action_reading_device_configuration {
            get {
                return ResourceManager.GetString("action_reading_device_configuration", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Refreshing device list.
        /// </summary>
        internal static string action_refreshing_device_list {
            get {
                return ResourceManager.GetString("action_refreshing_device_list", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting active source state.
        /// </summary>
        internal static string action_requesting_active_source_state {
            get {
                return ResourceManager.GetString("action_requesting_active_source_state", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting CEC version.
        /// </summary>
        internal static string action_requesting_cec_version {
            get {
                return ResourceManager.GetString("action_requesting_cec_version", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting menu language.
        /// </summary>
        internal static string action_requesting_menu_language {
            get {
                return ResourceManager.GetString("action_requesting_menu_language", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting OSD name.
        /// </summary>
        internal static string action_requesting_osd_name {
            get {
                return ResourceManager.GetString("action_requesting_osd_name", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting physical address.
        /// </summary>
        internal static string action_requesting_physical_address {
            get {
                return ResourceManager.GetString("action_requesting_physical_address", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting power status.
        /// </summary>
        internal static string action_requesting_power_status {
            get {
                return ResourceManager.GetString("action_requesting_power_status", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Requesting the vendor ID.
        /// </summary>
        internal static string action_requesting_vendor_id {
            get {
                return ResourceManager.GetString("action_requesting_vendor_id", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Sending the &apos;{0}&apos; command to {1}.
        /// </summary>
        internal static string action_sending_command_to {
            get {
                return ResourceManager.GetString("action_sending_command_to", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Sending power on commands.
        /// </summary>
        internal static string action_sending_power_on {
            get {
                return ResourceManager.GetString("action_sending_power_on", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Setting the new configuration.
        /// </summary>
        internal static string action_setting_new_libcec_configuration {
            get {
                return ResourceManager.GetString("action_setting_new_libcec_configuration", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Showing device information.
        /// </summary>
        internal static string action_showing_device_information {
            get {
                return ResourceManager.GetString("action_showing_device_information", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to close CECTray.
        /// </summary>
        internal static string action_type_close_controller_application {
            get {
                return ResourceManager.GetString("action_type_close_controller_application", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to generic.
        /// </summary>
        internal static string action_type_generic {
            get {
                return ResourceManager.GetString("action_type_generic", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to send key.
        /// </summary>
        internal static string action_type_sendkey {
            get {
                return ResourceManager.GetString("action_type_sendkey", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to start application.
        /// </summary>
        internal static string action_type_start_application {
            get {
                return ResourceManager.GetString("action_type_start_application", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Add new application.
        /// </summary>
        internal static string add_new_application {
            get {
                return ResourceManager.GetString("add_new_application", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The connection to the adapter was lost, probably because the device got unplugged..
        /// </summary>
        internal static string alert_connection_lost {
            get {
                return ResourceManager.GetString("alert_connection_lost", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to No permission from the OS to access the adapter. Please check your permissions..
        /// </summary>
        internal static string alert_permission_error {
            get {
                return ResourceManager.GetString("alert_permission_error", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The physical address that is assigned to the adapter is already being used. Please check your settings..
        /// </summary>
        internal static string alert_physical_address_error {
            get {
                return ResourceManager.GetString("alert_physical_address_error", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The device is being used by another program..
        /// </summary>
        internal static string alert_port_busy {
            get {
                return ResourceManager.GetString("alert_port_busy", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The device needs servicing. Please download and run the latest firmware upgrade from http://packages.pulse-eight.net/.
        /// </summary>
        internal static string alert_service_device {
            get {
                return ResourceManager.GetString("alert_service_device", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The TV does not respond to CEC polls. This is caused by one of the following:
        ///a) the TV does not support CEC;
        ///b) CEC has been disabled in the TV&apos;s settings;
        ///c) the HDMI cable between the TV and adapter is faulty.
        ///
        ///CEC will not work (properly) if the TV does not support CEC, or has CEC disabled in it&apos;s settings..
        /// </summary>
        internal static string alert_tv_poll_failed {
            get {
                return ResourceManager.GetString("alert_tv_poll_failed", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Send &apos;inactive source&apos; when shutting down the application.
        /// </summary>
        internal static string app_inactive_source {
            get {
                return ResourceManager.GetString("app_inactive_source", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Pulse-Eight USB-CEC Adapter - libCECTray.
        /// </summary>
        internal static string app_name {
            get {
                return ResourceManager.GetString("app_name", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Pause playback when switching to another source.
        /// </summary>
        internal static string app_pause_playback_on_deactivate {
            get {
                return ResourceManager.GetString("app_pause_playback_on_deactivate", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Send inactive source message when stopping the application.
        /// </summary>
        internal static string app_send_inactive_source {
            get {
                return ResourceManager.GetString("app_send_inactive_source", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Put this PC in standby mode when the TV is switched off.
        /// </summary>
        internal static string app_standby_on_tv_standby {
            get {
                return ResourceManager.GetString("app_standby_on_tv_standby", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Put devices in standby mode when activating screensaver.
        /// </summary>
        internal static string app_standby_screensaver {
            get {
                return ResourceManager.GetString("app_standby_screensaver", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Use the TV&apos;s language setting.
        /// </summary>
        internal static string app_use_tv_language {
            get {
                return ResourceManager.GetString("app_use_tv_language", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Foreground application.
        /// </summary>
        internal static string application_foreground {
            get {
                return ResourceManager.GetString("application_foreground", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Windows Media Center.
        /// </summary>
        internal static string application_windows_media_center {
            get {
                return ResourceManager.GetString("application_windows_media_center", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Kodi.
        /// </summary>
        internal static string application_xbmc {
            get {
                return ResourceManager.GetString("application_xbmc", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to - autodetect -.
        /// </summary>
        internal static string autodetect {
            get {
                return ResourceManager.GetString("autodetect", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Cannot open file &apos;{0}&apos;.
        /// </summary>
        internal static string cannot_open_file {
            get {
                return ResourceManager.GetString("cannot_open_file", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Cannot open &apos;{0}&apos; for writing.
        /// </summary>
        internal static string cannot_open_for_writing {
            get {
                return ResourceManager.GetString("cannot_open_for_writing", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Warning from libCEC.
        /// </summary>
        internal static string cec_alert {
            get {
                return ResourceManager.GetString("cec_alert", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to cec-log.txt.
        /// </summary>
        internal static string cec_log_filename {
            get {
                return ResourceManager.GetString("cec_log_filename", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to txt files (*.txt)|*.txt|All files (*.*)|*.*.
        /// </summary>
        internal static string cec_log_filter {
            get {
                return ResourceManager.GetString("cec_log_filter", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The command &apos;{0}&apos; was not acked..
        /// </summary>
        internal static string command_not_acked {
            get {
                return ResourceManager.GetString("command_not_acked", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Command sent successfully..
        /// </summary>
        internal static string command_sent_successfully {
            get {
                return ResourceManager.GetString("command_sent_successfully", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Mapped to.
        /// </summary>
        internal static string config_button_mapped_to {
            get {
                return ResourceManager.GetString("config_button_mapped_to", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to CEC Button.
        /// </summary>
        internal static string config_cec_button {
            get {
                return ResourceManager.GetString("config_cec_button", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Configure &apos;{0}&apos;.
        /// </summary>
        internal static string configure_application {
            get {
                return ResourceManager.GetString("configure_application", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Could not detect to any CEC adapter. Please check your configuration. Do you want to try again?.
        /// </summary>
        internal static string could_not_connect_try_again {
            get {
                return ResourceManager.GetString("could_not_connect_try_again", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Couldn&apos;t create directory &apos;{0}&apos;.
        /// </summary>
        internal static string could_not_create_directory {
            get {
                return ResourceManager.GetString("could_not_create_directory", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to AVR.
        /// </summary>
        internal static string device_audiosystem {
            get {
                return ResourceManager.GetString("device_audiosystem", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Broadcast.
        /// </summary>
        internal static string device_broadcast {
            get {
                return ResourceManager.GetString("device_broadcast", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Free Use.
        /// </summary>
        internal static string device_free_use {
            get {
                return ResourceManager.GetString("device_free_use", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Player.
        /// </summary>
        internal static string device_playbackdevice {
            get {
                return ResourceManager.GetString("device_playbackdevice", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Recorder.
        /// </summary>
        internal static string device_recorder {
            get {
                return ResourceManager.GetString("device_recorder", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Reserved.
        /// </summary>
        internal static string device_reserved {
            get {
                return ResourceManager.GetString("device_reserved", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Tuner.
        /// </summary>
        internal static string device_tuner {
            get {
                return ResourceManager.GetString("device_tuner", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to TV.
        /// </summary>
        internal static string device_tv {
            get {
                return ResourceManager.GetString("device_tv", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to You have changed the device type. Persist the configuration, and restart the application to use the new setting..
        /// </summary>
        internal static string device_type_changed {
            get {
                return ResourceManager.GetString("device_type_changed", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Error.
        /// </summary>
        internal static string error {
            get {
                return ResourceManager.GetString("error", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Executables (*.exe)|*.exe|All files (*.*)|*.*.
        /// </summary>
        internal static string exe_file_filter {
            get {
                return ResourceManager.GetString("exe_file_filter", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Make the media player the active source when starting.
        /// </summary>
        internal static string global_activate_source {
            get {
                return ResourceManager.GetString("global_activate_source", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Advanced mode.
        /// </summary>
        internal static string global_advanced_mode {
            get {
                return ResourceManager.GetString("global_advanced_mode", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Connected to HDMI device.
        /// </summary>
        internal static string global_connected_to_hdmi_device {
            get {
                return ResourceManager.GetString("global_connected_to_hdmi_device", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Device type.
        /// </summary>
        internal static string global_device_type {
            get {
                return ResourceManager.GetString("global_device_type", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Override physical address.
        /// </summary>
        internal static string global_override_physical_address {
            get {
                return ResourceManager.GetString("global_override_physical_address", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Override TV vendor.
        /// </summary>
        internal static string global_override_tv_vendor {
            get {
                return ResourceManager.GetString("global_override_tv_vendor", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Physical address.
        /// </summary>
        internal static string global_physical_address {
            get {
                return ResourceManager.GetString("global_physical_address", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Standby when stopping.
        /// </summary>
        internal static string global_standby_devices {
            get {
                return ResourceManager.GetString("global_standby_devices", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Minimise after connecting to the adapter.
        /// </summary>
        internal static string global_start_hidden {
            get {
                return ResourceManager.GetString("global_start_hidden", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Stop playback when the TV goes into standby.
        /// </summary>
        internal static string global_stop_tv_standby {
            get {
                return ResourceManager.GetString("global_stop_tv_standby", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to TV vendor.
        /// </summary>
        internal static string global_tv_vendor {
            get {
                return ResourceManager.GetString("global_tv_vendor", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Wake on startup.
        /// </summary>
        internal static string global_wake_devices {
            get {
                return ResourceManager.GetString("global_wake_devices", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Hide.
        /// </summary>
        internal static string hide {
            get {
                return ResourceManager.GetString("hide", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to The log file was stored as &apos;{0}&apos;..
        /// </summary>
        internal static string log_stored_as {
            get {
                return ResourceManager.GetString("log_stored_as", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to no.
        /// </summary>
        internal static string no {
            get {
                return ResourceManager.GetString("no", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Ready.
        /// </summary>
        internal static string ready {
            get {
                return ResourceManager.GetString("ready", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Please select the file to be executed.
        /// </summary>
        internal static string select_exe_file {
            get {
                return ResourceManager.GetString("select_exe_file", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Settings were stored.
        /// </summary>
        internal static string settings_stored {
            get {
                return ResourceManager.GetString("settings_stored", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Show.
        /// </summary>
        internal static string show {
            get {
                return ResourceManager.GetString("show", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Starting Kodi will exit this application, as only one program can be using the adapter at a time. Are you sure you want to proceed?.
        /// </summary>
        internal static string start_xbmc_exit_tray {
            get {
                return ResourceManager.GetString("start_xbmc_exit_tray", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Where do you want to store the settings file?.
        /// </summary>
        internal static string store_settings_where {
            get {
                return ResourceManager.GetString("store_settings_where", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Are you sure you want to proceed?.
        /// </summary>
        internal static string title_are_you_sure {
            get {
                return ResourceManager.GetString("title_are_you_sure", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to unknown.
        /// </summary>
        internal static string unknown {
            get {
                return ResourceManager.GetString("unknown", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME accept.
        /// </summary>
        internal static string VK_ACCEPT {
            get {
                return ResourceManager.GetString("VK_ACCEPT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to applications.
        /// </summary>
        internal static string VK_APPS {
            get {
                return ResourceManager.GetString("VK_APPS", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to backspace.
        /// </summary>
        internal static string VK_BACK {
            get {
                return ResourceManager.GetString("VK_BACK", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to control+break.
        /// </summary>
        internal static string VK_CANCEL {
            get {
                return ResourceManager.GetString("VK_CANCEL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to caps lock.
        /// </summary>
        internal static string VK_CAPITAL {
            get {
                return ResourceManager.GetString("VK_CAPITAL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to ctrl.
        /// </summary>
        internal static string VK_CONTROL {
            get {
                return ResourceManager.GetString("VK_CONTROL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME convert.
        /// </summary>
        internal static string VK_CONVERT {
            get {
                return ResourceManager.GetString("VK_CONVERT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to del.
        /// </summary>
        internal static string VK_DELETE {
            get {
                return ResourceManager.GetString("VK_DELETE", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to down arrow.
        /// </summary>
        internal static string VK_DOWN {
            get {
                return ResourceManager.GetString("VK_DOWN", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to ESC.
        /// </summary>
        internal static string VK_ESCAPE {
            get {
                return ResourceManager.GetString("VK_ESCAPE", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME final mode.
        /// </summary>
        internal static string VK_FINAL {
            get {
                return ResourceManager.GetString("VK_FINAL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME Hanguel mode.
        /// </summary>
        internal static string VK_HANGUEL {
            get {
                return ResourceManager.GetString("VK_HANGUEL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME Hangul mode.
        /// </summary>
        internal static string VK_HANGUL {
            get {
                return ResourceManager.GetString("VK_HANGUL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME Hanja mode.
        /// </summary>
        internal static string VK_HANJA {
            get {
                return ResourceManager.GetString("VK_HANJA", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to ins.
        /// </summary>
        internal static string VK_INSERT {
            get {
                return ResourceManager.GetString("VK_INSERT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME Junja mode.
        /// </summary>
        internal static string VK_JUNJA {
            get {
                return ResourceManager.GetString("VK_JUNJA", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME Kana mode.
        /// </summary>
        internal static string VK_KANA {
            get {
                return ResourceManager.GetString("VK_KANA", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME Kanji mode.
        /// </summary>
        internal static string VK_KANJI {
            get {
                return ResourceManager.GetString("VK_KANJI", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to start application 1.
        /// </summary>
        internal static string VK_LAUNCH_APP1 {
            get {
                return ResourceManager.GetString("VK_LAUNCH_APP1", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to start application 2.
        /// </summary>
        internal static string VK_LAUNCH_APP2 {
            get {
                return ResourceManager.GetString("VK_LAUNCH_APP2", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to start mail.
        /// </summary>
        internal static string VK_LAUNCH_MAIL {
            get {
                return ResourceManager.GetString("VK_LAUNCH_MAIL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to select media.
        /// </summary>
        internal static string VK_LAUNCH_MEDIA_SELECT {
            get {
                return ResourceManager.GetString("VK_LAUNCH_MEDIA_SELECT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to left mouse button.
        /// </summary>
        internal static string VK_LBUTTON {
            get {
                return ResourceManager.GetString("VK_LBUTTON", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to left control.
        /// </summary>
        internal static string VK_LCONTROL {
            get {
                return ResourceManager.GetString("VK_LCONTROL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to left arrow.
        /// </summary>
        internal static string VK_LEFT {
            get {
                return ResourceManager.GetString("VK_LEFT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to left menu.
        /// </summary>
        internal static string VK_LMENU {
            get {
                return ResourceManager.GetString("VK_LMENU", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to left shift.
        /// </summary>
        internal static string VK_LSHIFT {
            get {
                return ResourceManager.GetString("VK_LSHIFT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Windows key left.
        /// </summary>
        internal static string VK_LWIN {
            get {
                return ResourceManager.GetString("VK_LWIN", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to middle mouse button.
        /// </summary>
        internal static string VK_MBUTTON {
            get {
                return ResourceManager.GetString("VK_MBUTTON", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to next track.
        /// </summary>
        internal static string VK_MEDIA_NEXT_TRACK {
            get {
                return ResourceManager.GetString("VK_MEDIA_NEXT_TRACK", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to play/pause media.
        /// </summary>
        internal static string VK_MEDIA_PLAY_PAUSE {
            get {
                return ResourceManager.GetString("VK_MEDIA_PLAY_PAUSE", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to previous track.
        /// </summary>
        internal static string VK_MEDIA_PREV_TRACK {
            get {
                return ResourceManager.GetString("VK_MEDIA_PREV_TRACK", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to stop media.
        /// </summary>
        internal static string VK_MEDIA_STOP {
            get {
                return ResourceManager.GetString("VK_MEDIA_STOP", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to alt.
        /// </summary>
        internal static string VK_MENU {
            get {
                return ResourceManager.GetString("VK_MENU", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME mode change request.
        /// </summary>
        internal static string VK_MODECHANGE {
            get {
                return ResourceManager.GetString("VK_MODECHANGE", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to page down.
        /// </summary>
        internal static string VK_NEXT {
            get {
                return ResourceManager.GetString("VK_NEXT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME nonconvert.
        /// </summary>
        internal static string VK_NONCONVERT {
            get {
                return ResourceManager.GetString("VK_NONCONVERT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to num lock.
        /// </summary>
        internal static string VK_NUMLOCK {
            get {
                return ResourceManager.GetString("VK_NUMLOCK", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 0.
        /// </summary>
        internal static string VK_NUMPAD0 {
            get {
                return ResourceManager.GetString("VK_NUMPAD0", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 1.
        /// </summary>
        internal static string VK_NUMPAD1 {
            get {
                return ResourceManager.GetString("VK_NUMPAD1", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 2.
        /// </summary>
        internal static string VK_NUMPAD2 {
            get {
                return ResourceManager.GetString("VK_NUMPAD2", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 3.
        /// </summary>
        internal static string VK_NUMPAD3 {
            get {
                return ResourceManager.GetString("VK_NUMPAD3", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 4.
        /// </summary>
        internal static string VK_NUMPAD4 {
            get {
                return ResourceManager.GetString("VK_NUMPAD4", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 5.
        /// </summary>
        internal static string VK_NUMPAD5 {
            get {
                return ResourceManager.GetString("VK_NUMPAD5", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 6.
        /// </summary>
        internal static string VK_NUMPAD6 {
            get {
                return ResourceManager.GetString("VK_NUMPAD6", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 7.
        /// </summary>
        internal static string VK_NUMPAD7 {
            get {
                return ResourceManager.GetString("VK_NUMPAD7", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 8.
        /// </summary>
        internal static string VK_NUMPAD8 {
            get {
                return ResourceManager.GetString("VK_NUMPAD8", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to numeric keypad 9.
        /// </summary>
        internal static string VK_NUMPAD9 {
            get {
                return ResourceManager.GetString("VK_NUMPAD9", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to :; key.
        /// </summary>
        internal static string VK_OEM_1 {
            get {
                return ResourceManager.GetString("VK_OEM_1", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to /? key.
        /// </summary>
        internal static string VK_OEM_2 {
            get {
                return ResourceManager.GetString("VK_OEM_2", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to `~ key.
        /// </summary>
        internal static string VK_OEM_3 {
            get {
                return ResourceManager.GetString("VK_OEM_3", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to [{ key.
        /// </summary>
        internal static string VK_OEM_4 {
            get {
                return ResourceManager.GetString("VK_OEM_4", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to \| key.
        /// </summary>
        internal static string VK_OEM_5 {
            get {
                return ResourceManager.GetString("VK_OEM_5", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to ]} key.
        /// </summary>
        internal static string VK_OEM_6 {
            get {
                return ResourceManager.GetString("VK_OEM_6", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to &apos;&quot;&quot; key.
        /// </summary>
        internal static string VK_OEM_7 {
            get {
                return ResourceManager.GetString("VK_OEM_7", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to clear.
        /// </summary>
        internal static string VK_OEM_CLEAR {
            get {
                return ResourceManager.GetString("VK_OEM_CLEAR", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to , key.
        /// </summary>
        internal static string VK_OEM_COMMA {
            get {
                return ResourceManager.GetString("VK_OEM_COMMA", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to - key.
        /// </summary>
        internal static string VK_OEM_MINUS {
            get {
                return ResourceManager.GetString("VK_OEM_MINUS", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to . key.
        /// </summary>
        internal static string VK_OEM_PERIOD {
            get {
                return ResourceManager.GetString("VK_OEM_PERIOD", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to + key.
        /// </summary>
        internal static string VK_OEM_PLUS {
            get {
                return ResourceManager.GetString("VK_OEM_PLUS", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to unicode packet.
        /// </summary>
        internal static string VK_PACKET {
            get {
                return ResourceManager.GetString("VK_PACKET", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to page up.
        /// </summary>
        internal static string VK_PRIOR {
            get {
                return ResourceManager.GetString("VK_PRIOR", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to IME PROCESS.
        /// </summary>
        internal static string VK_PROCESSKEY {
            get {
                return ResourceManager.GetString("VK_PROCESSKEY", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to right mouse button.
        /// </summary>
        internal static string VK_RBUTTON {
            get {
                return ResourceManager.GetString("VK_RBUTTON", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to right control.
        /// </summary>
        internal static string VK_RCONTROL {
            get {
                return ResourceManager.GetString("VK_RCONTROL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to enter.
        /// </summary>
        internal static string VK_RETURN {
            get {
                return ResourceManager.GetString("VK_RETURN", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to right arrow.
        /// </summary>
        internal static string VK_RIGHT {
            get {
                return ResourceManager.GetString("VK_RIGHT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to right menu.
        /// </summary>
        internal static string VK_RMENU {
            get {
                return ResourceManager.GetString("VK_RMENU", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to right shift.
        /// </summary>
        internal static string VK_RSHIFT {
            get {
                return ResourceManager.GetString("VK_RSHIFT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Windows key right.
        /// </summary>
        internal static string VK_RWIN {
            get {
                return ResourceManager.GetString("VK_RWIN", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to scroll lock.
        /// </summary>
        internal static string VK_SCROLL {
            get {
                return ResourceManager.GetString("VK_SCROLL", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to print screen.
        /// </summary>
        internal static string VK_SNAPSHOT {
            get {
                return ResourceManager.GetString("VK_SNAPSHOT", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to spacebar.
        /// </summary>
        internal static string VK_SPACE {
            get {
                return ResourceManager.GetString("VK_SPACE", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to up arrow.
        /// </summary>
        internal static string VK_UP {
            get {
                return ResourceManager.GetString("VK_UP", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to X1 mouse button.
        /// </summary>
        internal static string VK_XBUTTON1 {
            get {
                return ResourceManager.GetString("VK_XBUTTON1", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to X2 mouse button.
        /// </summary>
        internal static string VK_XBUTTON2 {
            get {
                return ResourceManager.GetString("VK_XBUTTON2", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to Where do you want to store the log file?.
        /// </summary>
        internal static string where_do_you_want_to_store_the_log {
            get {
                return ResourceManager.GetString("where_do_you_want_to_store_the_log", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to xml files (*.xml)|*.xml|All files (*.*)|*.*.
        /// </summary>
        internal static string xml_file_filter {
            get {
                return ResourceManager.GetString("xml_file_filter", resourceCulture);
            }
        }
        
        /// <summary>
        ///   Looks up a localized string similar to yes.
        /// </summary>
        internal static string yes {
            get {
                return ResourceManager.GetString("yes", resourceCulture);
            }
        }
    }
}
