/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2013 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

using System;
using System.Windows.Forms;
using LibCECTray.controller.applications;
using LibCECTray.ui;

namespace LibCECTray
{
  static class Program
  {
    private static CECTray _instance;
    public static CECTray Instance
    {
      get
      {
        if (_instance == null)
        {
          _instance = new CECTray();
          if (_instance == null)
            throw new Exception("Failed to load libCEC. Check whether cec.dll is present in the same directory as LibCecSharp.dll");
          _instance.Initialise();
        }
        return _instance;
      }
    }

    [STAThread]
    static void Main()
    {
      var instance = WindowsAPI.RunningInstance();
      if (instance == null)
      {
        Application.EnableVisualStyles();
        Application.SetCompatibleTextRenderingDefault(false);
        try
        {
          Application.Run(Instance);
        } catch (Exception e)
        {
          MessageBox.Show(e.Message);
        }
      }
      else
      {
        WindowsAPI.ShowWindowAsync(instance.MainWindowHandle, (int)WindowsAPI.ShowType.ShowNormal);
        WindowsAPI.SetForegroundWindow(instance.MainWindowHandle);
      }
    }
  }
}
