/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2013 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

using CecSharp;
using LibCECTray.Properties;

namespace LibCECTray.controller.actions
{
  class UpdateConnectedDevice : UpdateProcess
  {
    public UpdateConnectedDevice(LibCecSharp lib, CecLogicalAddress address, int portNumber)
    {
      _lib = lib;
      _address = address;
      _portNumber = portNumber;
    }

    public override void Process()
    {
      SendEvent(UpdateEventType.StatusText, Resources.action_requesting_physical_address);
      SendEvent(UpdateEventType.ProgressBar, 0);

      var iPhysicalAddress = _lib.GetDevicePhysicalAddress(_address);
      SendEvent(UpdateEventType.BaseDevicePhysicalAddress, iPhysicalAddress);

      SendEvent(UpdateEventType.StatusText, Resources.action_setting_new_libcec_configuration);
      SendEvent(UpdateEventType.ProgressBar, 25);

      if (!_lib.SetHDMIPort(_address, (byte)_portNumber))
      {
        SendEvent(UpdateEventType.StatusText, string.Format(Resources.command_not_acked, "SetHDMIPort"));
      }
      else
      {
        LibCECConfiguration config = new LibCECConfiguration();
        _lib.GetCurrentConfiguration(config);

        SendEvent(UpdateEventType.StatusText, Resources.action_activating_source);
        SendEvent(UpdateEventType.ProgressBar, 50);
        _lib.SetActiveSource(config.DeviceTypes.Types[0]);

        SendEvent(UpdateEventType.StatusText, Resources.action_reading_device_configuration);
        SendEvent(UpdateEventType.ProgressBar, 75);
        _lib.GetCurrentConfiguration(config);

        SendEvent(config);
        SendEvent(UpdateEventType.StatusText, Resources.ready);
      }
      SendEvent(UpdateEventType.ProgressBar, 100);
    }

    private readonly LibCecSharp       _lib;
    private readonly CecLogicalAddress _address;
    private readonly int               _portNumber;
  }
}
